Vue principale d'un projet
--------------------------

.. image:: /data/wdoc/interface_fr.jpg
     :width: 500
     :alt: vue principale d'un projet
     :align: center

1. La boîte des actions
   Ce sont la liste des actions disponibles pour l'élément en cours. L'action la plus générique est `modifier` qui vous permet ensuite d'ajouter des relations entre cet élément et d'autres éléments du site. Les autres actions proposés sont en fait des raccourcis de ce que vous pourriez faire dans la page de modification.

2. La liste des versions en cours
   Seules les versions actuellement développées sont affichées. Il est néanmoins possible de lister l'ensemble des versions existantes avec le lien texte proposé.

3. La vue principale des tickets pour ce projet. Cette vue peut être filtrée à l'aide de la boîte de recherche accessible en cliquant sur l'icône en forme de ciseau en haut à droite de ce cadre.

4. Les informations connexes qui sont répresente les relations existantes pour le projet. Vous retrouvez ces informations en cliquant sur l'action `modifier`.


Édition des relations pour un élément
-------------------------------------
Pour accéder à cette page, vous devez utiliser l'action `modifier`. L'édition des relations se fait ensuite à l'aide de menus déroulants.

.. image:: data/wdoc/relations_fr.jpg
     :alt: boîte d'édition des relation
     :align: center
